import { Directive, ElementRef, EventEmitter, Input, NgModule, Output, Renderer2 } from '@angular/core';

module.exports = require("./lib/dropzone.js"); // Exposing dropzone


var Dropzone = Object.freeze({

});

class ADropzoneDirective {
    /**
     * @param {?} el
     * @param {?} renderer2
     */
    constructor(el, renderer2) {
        this.el = el;
        this.renderer2 = renderer2;
        /* -------------- Events Output -------------- */
        this.drop = new EventEmitter();
        this.dragstart = new EventEmitter();
        this.dragenter = new EventEmitter();
        this.dragend = new EventEmitter();
        this.dragover = new EventEmitter();
        this.dragleave = new EventEmitter();
        /* -------------- File Output -------------- */
        this.addedfile = new EventEmitter();
        this.removedfile = new EventEmitter();
        this.thumbnail = new EventEmitter();
        this.error = new EventEmitter();
        this.processing = new EventEmitter();
        this.uploadprogress = new EventEmitter();
        this.sending = new EventEmitter();
        this.success = new EventEmitter();
        this.complete = new EventEmitter();
        this.canceled = new EventEmitter();
        this.maxfilesreached = new EventEmitter();
        this.maxfilesexceeded = new EventEmitter();
        this.initOptionVariable();
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.init();
        this.setStyles();
    }
    /**
     * @param {?} changes
     * @return {?}
     */
    ngOnChanges(changes) {
        if (changes['options']) {
            this._options = Object.assign(this._options, this.options);
            this.destroy();
            this.init();
        }
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        this.destroy();
    }
    /**
     * @return {?}
     */
    initOptionVariable() {
        const /** @type {?} */ _this = this;
        this._options = {
            url: '#',
            init: function () {
                this.on('drop', function (event) {
                    _this.drop.emit(event);
                });
                this.on('dragstart', function (event) {
                    _this.dragstart.emit(event);
                });
                this.on('dragend', function (event) {
                    _this.dragend.emit(event);
                });
                this.on('dragenter', function (event) {
                    _this.dragenter.emit(event);
                });
                this.on('dragover', function (event) {
                    _this.dragover.emit(event);
                });
                this.on('dragleave', function (event) {
                    _this.dragleave.emit(event);
                });
                this.on('drop', function (event) {
                    _this.drop.emit(event);
                });
                this.on('dragstart', function (event) {
                    _this.dragstart.emit(event);
                });
                this.on('dragend', function (event) {
                    _this.dragend.emit(event);
                });
                this.on('dragenter', function (event) {
                    _this.dragenter.emit(event);
                });
                this.on('dragover', function (event) {
                    _this.dragover.emit(event);
                });
                this.on('dragleave', function (event) {
                    _this.dragleave.emit(event);
                });
                this.on('addedfile', function (file) {
                    _this.addedfile.emit(file);
                });
                this.on('removedfile', function (file) {
                    _this.removedfile.emit(file);
                });
                this.on('thumbnail', function (file) {
                    _this.thumbnail.emit(file);
                });
                this.on('error', function (file) {
                    _this.error.emit(file);
                });
                this.on('processing', function (file) {
                    _this.processing.emit(file);
                });
                this.on('uploadprogress', function (file) {
                    _this.uploadprogress.emit(file);
                });
                this.on('sending', function (file) {
                    _this.sending.emit(file);
                });
                this.on('success', function (file) {
                    _this.success.emit(file);
                });
                this.on('complete', function (file) {
                    _this.complete.emit(file);
                });
                this.on('canceled', function (file) {
                    _this.canceled.emit(file);
                });
                this.on('maxfilesreached', function (file) {
                    _this.maxfilesreached.emit(file);
                });
                this.on('maxfilesexceeded', function (file) {
                    _this.maxfilesexceeded.emit(file);
                });
            }
        };
    }
    /**
     * @return {?}
     */
    setStyles() {
        this.renderer2.setStyle(this.el.nativeElement, 'border', '1px dashed gray');
    }
    /**
     * @return {?}
     */
    init() {
        this.dropzone = new Dropzone(this.el.nativeElement, this._options);
    }
    /**
     * @return {?}
     */
    destroy() {
        this.dropzone.destroy();
    }
}
ADropzoneDirective.decorators = [
    { type: Directive, args: [{ selector: '[a-dropzone]' },] },
];
/**
 * @nocollapse
 */
ADropzoneDirective.ctorParameters = () => [
    { type: ElementRef, },
    { type: Renderer2, },
];
ADropzoneDirective.propDecorators = {
    'options': [{ type: Input },],
    'drop': [{ type: Output },],
    'dragstart': [{ type: Output },],
    'dragenter': [{ type: Output },],
    'dragend': [{ type: Output },],
    'dragover': [{ type: Output },],
    'dragleave': [{ type: Output },],
    'addedfile': [{ type: Output },],
    'removedfile': [{ type: Output },],
    'thumbnail': [{ type: Output },],
    'error': [{ type: Output },],
    'processing': [{ type: Output },],
    'uploadprogress': [{ type: Output },],
    'sending': [{ type: Output },],
    'success': [{ type: Output },],
    'complete': [{ type: Output },],
    'canceled': [{ type: Output },],
    'maxfilesreached': [{ type: Output },],
    'maxfilesexceeded': [{ type: Output },],
};

class ADropzoneModule {
}
ADropzoneModule.decorators = [
    { type: NgModule, args: [{
                declarations: [ADropzoneDirective],
                exports: [ADropzoneDirective]
            },] },
];
/**
 * @nocollapse
 */
ADropzoneModule.ctorParameters = () => [];

/**
 * Generated bundle index. Do not edit.
 */

export { ADropzoneDirective, ADropzoneModule };
//# sourceMappingURL=a-dropzone.js.map
